Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TemplateData ¶
func TemplateData(p string, data interface{})
An alias for TemplateOpts, with default options and user data Not Implemented
Types ¶
type Options ¶
type Options struct {
// The keyword used on the Ctx map to find the template name.
CtxTemplateKeyword string
// Ignore any encountered template errors, and simply return
// the raw data.
IgnoreTemplateErrors bool
// If found, include the front matter into the template's data
IncludeFrontMatter bool
}
Click to show internal directories.
Click to hide internal directories.